package arbre_ini;

import java.util.ArrayList;

/**
 * 
 * @author santini
 * 
 * Définition et gestion d'un noeud racine
 *
 */
public class NoeudRacine extends Noeud implements Sujet {
	
	// la liste des noeuds fils devant être notifié d'un changement d'état de l'instance
	private ArrayList<Observateur> observateurs ;
	
	/**
	 * Constructeur champ à champ.
	 * @param n le nom du noeud racine.
	 * @param v la valeur du noeud racine.
	 * @param c le coefficient du noeud racine.
	 */
	public NoeudRacine(String n, Integer v, Integer c) {
		super(n,v,c);
		this.observateurs = new ArrayList<Observateur>();
	}
	
	/**
	 * Ajoute un observateur devant être notifié d'un changement d'état du noeud.
	 * @param o l'observateur à ajouter s'abonnant aux notifications de modification de l'état du noeud racine.
	 */
	public void ajouterObservateur(Observateur o) {
		this.observateurs.add(o);
	}
	
	/**
	 * Supprime un des observateurs de sujet.
	 * @param o l'observateur à supprimer se désabonnant des notifications de modification de l'état du noeud racine.
	 */
	public void supprimerObservateur(Observateur o) {
		this.observateurs.remove(0);
	}
	
	/**
	 * Notifie à tous les abonnés d'une modification de l'état du noeud racine.
	 */
	public void notifierObservateurs() {
		for( Observateur o : this.observateurs) {
			o.actualiser(this);
		}
	}

	/**
	 * 
	 * @ param v la valeur incidente au noeud provoquant son changement d'état et la notification de ce changment à ses observateurs.
	 */
	public void majValeur(Integer v) {
		super.majValeur(v);
		this.notifierObservateurs();
	}
}
